==> truth-proto-extension-1.1.3-sources.jar: com/google/common/truth/extensions/proto/AutoValue_DiffResult_SingularField.java <==
package com.google.common.truth.extensions.proto;

import com.google.common.base.Optional;
import com.google.errorprone.annotations.concurrent.LazyInit;
import java.lang.Iterable;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;

final class AutoValue_DiffResult_SingularField extends $AutoValue_DiffResult_SingularField {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile Object actualOrExpected;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile Iterable<? extends RecursableDiffEntity> childEntities;

  AutoValue_DiffResult_SingularField(RecursableDiffEntity.WithResultCode.Result result$,
      Optional<SubScopeId> subScopeId$, String fieldName$, Optional<Object> actual$,
      Optional<Object> expected$, Optional<DiffResult> breakdown$,
      Optional<DiffResult.UnknownFieldSetDiff> unknownsBreakdown$) {
    super(result$, subScopeId$, fieldName$, actual$, expected$, breakdown$, unknownsBreakdown$);
  }

  @Override
  Object actualOrExpected() {
    if (actualOrExpected == null) {
      synchronized (this) {
        if (actualOrExpected == null) {
          actualOrExpected = super.actualOrExpected();
          if (actualOrExpected == null) {
            throw new NullPointerException("actualOrExpected() cannot return null");
          }
        }
      }
    }
    return actualOrExpected;
  }

  @Override
  Iterable<? extends RecursableDiffEntity> childEntities() {
    if (childEntities == null) {
      synchronized (this) {
        if (childEntities == null) {
          childEntities = super.childEntities();
          if (childEntities == null) {
            throw new NullPointerException("childEntities() cannot return null");
          }
        }
      }
    }
    return childEntities;
  }
}

==> truth-proto-extension-1.4.4-sources.jar: com/google/common/truth/extensions/proto/AutoValue_DiffResult_SingularField.java <==
package com.google.common.truth.extensions.proto;

import com.google.common.base.Optional;
import com.google.errorprone.annotations.concurrent.LazyInit;
import com.google.protobuf.TextFormat;
import java.lang.Iterable;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;

final class AutoValue_DiffResult_SingularField extends $AutoValue_DiffResult_SingularField {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile Object actualOrExpected;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile Iterable<? extends RecursableDiffEntity> childEntities;

  AutoValue_DiffResult_SingularField(TextFormat.Printer protoPrinter,
      RecursableDiffEntity.WithResultCode.Result result, Optional<SubScopeId> subScopeId,
      String fieldName, Optional<Object> actual, Optional<Object> expected,
      Optional<DiffResult> breakdown, Optional<DiffResult.UnknownFieldSetDiff> unknownsBreakdown) {
    super(protoPrinter, result, subScopeId, fieldName, actual, expected, breakdown, unknownsBreakdown);
  }

  @Override
  Object actualOrExpected() {
    if (actualOrExpected == null) {
      synchronized (this) {
        if (actualOrExpected == null) {
          actualOrExpected = super.actualOrExpected();
          if (actualOrExpected == null) {
            throw new NullPointerException("actualOrExpected() cannot return null");
          }
        }
      }
    }
    return actualOrExpected;
  }

  @Override
  Iterable<? extends RecursableDiffEntity> childEntities() {
    if (childEntities == null) {
      synchronized (this) {
        if (childEntities == null) {
          childEntities = super.childEntities();
          if (childEntities == null) {
            throw new NullPointerException("childEntities() cannot return null");
          }
        }
      }
    }
    return childEntities;
  }
}
